struct AbstractFunc {
handler: AbstractFuncHandler,
pushdownable: (bool, bool),
}Expand description
The abstract-domain counterpart of a BinaryFunc: a binary function we’ve added special-case handling for; including:
- Either a complete override of ResultSpec computation, or a way to compute monotonicity dynamically from the input specs.
- Metadata on whether / not this function is pushdownable. See Trace.
Note: today a function can have either a handler override or a dynamic-monotonicity verdict, but not both. If a future function wants both, promote AbstractFuncHandler from an enum to a struct with two optional fields.
Fields
handler: AbstractFuncHandlerpushdownable: (bool, bool)(left, right): per-argument pushdownability hint consumed by
Trace. true for an argument means the function preserves enough
structure that, with sufficient information about that argument’s
range, the output spec can be predicted — i.e. the predicate is a
pushdown candidate when that argument is constant or a tight range.
Implementations
Sourceimpl AbstractFunc
impl AbstractFunc
Sourcefn for_func(func: &BinaryFunc) -> Option<AbstractFunc>
fn for_func(func: &BinaryFunc) -> Option<AbstractFunc>
Returns the special-case handling for a particular function, if it exists.